@@ -474,6 +474,9 @@ class Element(object):
         True if element is a actinoid.
         """
         return self.Z > 88 and self.Z < 104
+    
+    def __deepcopy__(self, memo):
+        return Element(self.symbol)
 
 
 class Specie(Element):
@@ -521,7 +524,8 @@ class Specie(Element):
         '''
         Sets a default sort order for atomic species by electronegativity, followed by oxidation state. 
         '''
-        return (self.X - other.X) * 100 + (self.oxi_state - other.oxi_state)
+        other_oxi = 0 if isinstance(other, Element) else other.oxi_state
+        return (self.X - other.X) * 100 + (self.oxi_state - other_oxi)
     
     @property
     def ionic_radius(self):
@@ -569,6 +573,9 @@ class Specie(Element):
         else:
             output += formula_double_format(- self.oxi_state) + "-"
         return output
+    
+    def __deepcopy__(self, memo):
+        return Specie(self.symbol, self.oxi_state)
 
 @singleton
 class PeriodicTable(object):
